"""
Material is a script to set the material preference for the skeinforge chain.

To run material, install python 2.x on your machine, which is avaliable from http://www.python.org/download/

Then in the folder which material is in, type 'python' in a shell to run the python interpreter.  Finally type
'from material import *' to import this program.
To get documentation for this program, open a shell in the fill.py directory, then type 'pydoc material.py'.


This example analyzes and comments the gcode file Hollow Square.gcode.  This example is run in a terminal in the folder which contains Hollow Square.gcode and material.py.

>>> import fillet
Fillet has been imported.
The gcode files in this directory that are not already beveled or filleted are the following:
['Hollow Square.gcode']


>>> fillet.arcPoint()
File Hollow Square.gcode is being filleted into arc points.
( GCode generated by March 29,2007 Skeinforge )
( Extruder Initialization )
..
many lines of gcode
..
The arc point file is saved as Hollow Square_arc_point.gcode

"""

from skeinforge_utilities import gcodec
from skeinforge_utilities import preferences


__author__ = "Enrique Perez (perez_enrique@yahoo.com)"
__date__ = "$Date: 2008/21/04 $"
__license__ = "GPL 3.0"


def getSelectedMaterial():
	"Get the selected material."
	materialPreferences = MaterialPreferences()
	preferences.readPreferences( materialPreferences )
	return materialPreferences.materialListbox.value


class MaterialPreferences:
	"A class to handle the material preferences."
	def __init__( self ):
		"Set the default preferences, execute title & preferences filename."
		#Set the default preferences.
		self.materialList = preferences.ListPreference().getFromValue( 'Material List:', [ 'ABS', 'HDPE', 'PCL', 'PLA' ] )
		self.materialListbox = preferences.ListboxPreference().getFromListPreference( self.materialList, 'Material Selection:', 'ABS' )
		self.addListboxSelection = preferences.AddListboxSelection().getFromListboxPreference( self.materialListbox )
		self.deleteListboxSelection = preferences.DeleteListboxSelection().getFromListboxPreference( self.materialListbox )
		#Create the archive, title of the dialog & preferences filename.
		self.archive = [ self.materialList, self.materialListbox, self.addListboxSelection, self.deleteListboxSelection ]
		self.executeTitle = None
		self.filenameHelp = 'material.html'
		self.filenamePreferences = preferences.getPreferencesFilePath( 'material.csv' )
		self.title = 'Material Preferences'


def main( hashtable = None ):
	"Display the material dialog."
	preferences.displayDialog( MaterialPreferences() )

if __name__ == "__main__":
	main()
